==> ver.B.b14.01.tar.gz: ver.B.b14.01/env/src/xl/function/IfDef.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"xlerror.h"
#include	"xl.h"

XL_SEXP * xl_IfDef();


void
init_IfDef(XLISP_ENV * env)
{
	set_env(env,l_string(std_cm,"IfDef"),
		get_func_prim(xl_IfDef,FO_NORMAL,0,3,3));
}

XL_SEXP *
xl_IfDef(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
{
XL_SEXP * sym;
XL_SEXP * ret;
L_CHAR * depth;
 	sym = get_el(s,1);
	if ( get_type(sym) != XLT_SYMBOL )
		goto type_missmatch;
	depth = get_sf_attribute(sf,l_string(std_cm,"depth"));
	if ( depth ) {
		if ( get_env_symbol(env,sym->symbol.data,atoi(n_string(std_cm,depth))) == 0 )
			goto misshit;
	}
	ret = eval(env,sym);
	if ( get_type(ret) == XLT_ERROR )
		goto misshit;
	return ret;
misshit:
	return eval(env,get_el(s,2));
type_missmatch:
	return get_error(
		s->h.file,
		s->h.line,
		XLE_SEMANTICS_TYPE_MISSMATCH,
		l_string(std_cm,"IfDef"),
		0);
/*
internal_error:
	return get_error(
		s->h.file,
		s->h.line,
		XLE_SYSTEM_INTERNAL,
		l_string(std_cm,"IfDef"),
		n_get_string("shell IfDefments initializing is required"));
*/
}

==> ver.B.b17.12.tar.gz: ver.B.b17.12/env/src/xl/function/IfDef.c <==
/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/


#include	"xlerror.h"
#include	"xl.h"

XL_SEXP * xl_IfDef();


void
init_IfDef(XLISP_ENV * env)
{
	set_env(env,l_string(std_cm,"IfDef"),
		get_func_prim(xl_IfDef,FO_NORMAL,0,3,3));
}

XL_SEXP *
xl_IfDef(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
{
XL_SEXP * sym;
XL_SEXP * ret;
L_CHAR * depth;
 	sym = get_el(s,1);
	if ( get_type(sym) != XLT_SYMBOL ) {
		sym = eval(env,sym);
		switch ( get_type(sym) ) {
		case XLT_SYMBOL:
			break;
		case XLT_ERROR:
			return sym;
		default:
			goto type_missmatch;
		}
	}
	depth = get_sf_attribute(sf,l_string(std_cm,"depth"));
	if ( depth ) {
		if ( get_env_symbol(env,sym->symbol.data,atoi(n_string(std_cm,depth))) == 0 )
			goto misshit;
	}
	ret = eval(env,sym);
	if ( get_type(ret) == XLT_ERROR )
		goto misshit;
	return ret;
misshit:
	return eval(env,get_el(s,2));
type_missmatch:
	return get_error(
		s->h.file,
		s->h.line,
		XLE_SEMANTICS_TYPE_MISSMATCH,
		l_string(std_cm,"IfDef"),
		0);
/*
internal_error:
	return get_error(
		s->h.file,
		s->h.line,
		XLE_SYSTEM_INTERNAL,
		l_string(std_cm,"IfDef"),
		n_get_string("shell IfDefments initializing is required"));
*/
}
